@@ -9,20 +9,22 @@
 #define OPENBLAS_BUNDERSCORE _
 #define OPENBLAS_NEEDBUNDERSCORE 1
 #define OPENBLAS_ARMV8 
-#define OPENBLAS_HAVE_NEON 
-#define OPENBLAS_HAVE_VFPV4 
-#define OPENBLAS_CORTEXA53 
 #define OPENBLAS_L1_DATA_SIZE 32768
 #define OPENBLAS_L1_DATA_LINESIZE 64
 #define OPENBLAS_L2_SIZE 262144
 #define OPENBLAS_L2_LINESIZE 64
 #define OPENBLAS_DTB_DEFAULT_ENTRIES 64
 #define OPENBLAS_DTB_SIZE 4096
-#define OPENBLAS_L2_ASSOCIATIVE 4
-#define OPENBLAS_NUM_CORES 6
-#define OPENBLAS_CHAR_CORENAME "CORTEXA53"
+#define OPENBLAS_L2_ASSOCIATIVE 32
+#define OPENBLAS_HAVE_VFPV4 
+#define OPENBLAS_HAVE_VFPV3 
+#define OPENBLAS_HAVE_VFP 
+#define OPENBLAS_HAVE_NEON 
+#define OPENBLAS_ARMV8 
+#define OPENBLAS_CORE_ARMV8 
+#define OPENBLAS_CHAR_CORENAME "ARMV8"
 #define OPENBLAS_GEMM_MULTITHREAD_THRESHOLD 4
-#define OPENBLAS_VERSION " OpenBLAS 0.3.12 "
+#define OPENBLAS_VERSION " OpenBLAS 0.3.13 "
 /*This is only for "make install" target.*/
 
 #if defined(OPENBLAS_OS_WINNT) || defined(OPENBLAS_OS_CYGWIN_NT) || defined(OPENBLAS_OS_INTERIX)
